Start Romagna
Description: Start, la nuova grande realtà del trasporto pubblico in Romagna.

# Richiedi Informazioni

# Start Romagna è a tua disposizione per qualsiasi richiesta.

Compila il modulo per richiedere informazioni relative al servizio del Trasporto Pubblico locale in Romagna.

I campi contrassegnati con * sono obbligatori.

- Nome*
- Cognome*
- Telefono*
- Email*
- Località*
  Linea n°

  Inserisci la località coinvolta dal servizio e la linea per la quale richiedi informazioni a Start Romagna.

- Messaggio*

#### Informativa e consenso al trattamento dei dati personali

- Start Romagna, in qualità di titolare dei suoi dati personali, la informa che ai sensi dell’art. 13 del D. Lgs. 196 del 30/06/2003 i suoi dati saranno trattati nel rispetto della normativa citata. Lei gode dei diritti previsti dal citato decreto e le vengono riconosciuti i diritti di cui all’art. 7 che potranno essere esercitati rivolgendosi al Titolare o al Responsabile del trattamento dei dati di Start Romagna.

  Acconsento al trattamento dei miei dati*

## Area Riservata Start&You

Username o Email
Password
Ricordami Password dimenticata?

Non hai ancora un account?
Scopri i vantaggi del mondo Start

Registrati
Adesso